<template>
    <div class="container">
        <div class="header">
            <div class="title">
                <i class="title-icon"></i>
                <span class="title-text">专项巡查统计</span>
            </div>
            <i class="back-icon" @click="handleReset"></i>
        </div>
        <div class="search">
            <el-date-picker
                v-model="startTime"
                type="date"
                placeholder="请选择开始日期"
                value-format="yyyy-MM-dd"
            >
            </el-date-picker>
            <el-date-picker
                v-model="endTime"
                type="date"
                placeholder="请选择结束日期"
                value-format="yyyy-MM-dd"
            >
            </el-date-picker>
            <el-button size="small" @click="loadData" type="primary">查询</el-button>
            <el-button size="small" @click="reset" type="plain"> 重置 </el-button>
        </div>
        <div class="table">
            <!-- height="100%" -->
            <el-table
                :data="tableData"
                stripe
                border
                show-summary
                v-loading="loading"
                :span-method="objectSpanMethod"
                @row-click="hanldeRowClick"
                @cell-click="handleCellClick"
                header-cell-class-name="custom-header-cell"
                cell-class-name="custom-cell"
            >
                <el-table-column label="序号" type="index" width="70" align="center">
                    <template v-slot="{$index}">
                        {{ `${($index + 3) / 3}` }}
                    </template>
                </el-table-column>
                <el-table-column width="160" align="center" prop="name" label="单位名称">
                    <template v-slot="{row}">
                        <i class="el-icon-arrow-down" style="margin-right: 10px"></i>
                        {{ row.name }}
                    </template>
                </el-table-column>
                <el-table-column
                    label="检查状态"
                    align="center"
                    prop="statusName"
                ></el-table-column>
                <el-table-column label="定期检查" align="center">
                    <el-table-column
                        align="center"
                        prop="check-Bridge"
                        label="桥梁"
                        column-key="check-Bridge"
                    >
                    </el-table-column>
                    <el-table-column
                        align="center"
                        prop="check-Slope"
                        label="边坡"
                        column-key="check-Slope"
                    >
                    </el-table-column>
                    <el-table-column
                        align="center"
                        prop="check-Culvert"
                        label="涵洞"
                        column-key="check-Culvert"
                    >
                    </el-table-column>
                    <el-table-column
                        align="center"
                        prop="check-Tunnel"
                        label="隧道"
                        column-key="check-Tunnel"
                    >
                    </el-table-column>
                </el-table-column>
                <el-table-column label="经常检查" align="center">
                    <el-table-column
                        align="center"
                        prop="of-Bridge"
                        label="桥梁"
                        column-key="of-Bridge"
                    >
                    </el-table-column>
                    <el-table-column
                        align="center"
                        prop="of-Slope"
                        label="边坡"
                        column-key="of-Slope"
                    >
                    </el-table-column>
                    <el-table-column
                        align="center"
                        prop="of-Culvert"
                        label="涵洞"
                        column-key="of-Culvert"
                    >
                    </el-table-column>
                    <el-table-column
                        align="center"
                        prop="of-Tunnel"
                        label="隧道"
                        column-key="of-Tunnel"
                    >
                    </el-table-column>
                </el-table-column>
                <el-table-column label="常规检查" align="center">
                    <el-table-column
                        align="center"
                        prop="special-Bridge"
                        label="桥梁"
                        column-key="special-Bridge"
                    >
                    </el-table-column>
                    <el-table-column
                        align="center"
                        prop="special-Tunnel"
                        label="隧道"
                        column-key="special-Tunnel"
                    >
                    </el-table-column>
                </el-table-column>
            </el-table>
        </div>
    </div>
</template>

<script>
import moment from 'moment'
const pathMap = [
    {path: 'regularInspection#regularInspectionBridges', key: 'check-Bridge'},
    {path: 'regularInspection#regularInspectionSlope', key: 'check-Slope'},
    {
        path: 'regularInspection#regularInspectionCulvert',
        key: 'check-Culvert',
    },
    {path: 'regularInspection#regularInspectionTunnel', key: 'check-Tunnel'},

    {path: 'checkFrequently#frequentInspectionBridges', key: 'of-Bridge'},
    {path: 'checkFrequently#frequentInspectionSlope', key: 'of-Slope'},
    {path: 'checkFrequently#frequentInspectionCulverts', key: 'of-Culvert'},
    {path: 'checkFrequently#frequentInspectionTunnels', key: 'of-Tunnel'},
    {
        path: 'specialProjectInspection#specialInspectionBridge',
        key: 'special-Bridge',
    },
    {
        path: 'specialProjectInspection#specialInspectionTunnel',
        key: 'special-Tunnel',
    },
]
const finish = [
    {key: 'checkFinishedBridge', name: 'Bridge'},
    {key: 'checkFinishedCulvert', name: 'Culvert'},
    {key: 'checkFinishedSlope', name: 'Slope'},
    {key: 'checkFinishedTunnel', name: 'Tunnel'},
]
const unfinish = [
    {key: 'checkUnfinishedBridge', name: 'Bridge'},
    {key: 'checkUnfinishedCulvert', name: 'Culvert'},
    {key: 'checkUnfinishedSlope', name: 'Slope'},
    {key: 'checkUnfinishedTunnel', name: 'Tunnel'},
]
const coming = [
    {key: 'checkComingBridge', name: 'Bridge'},
    {key: 'checkComingCulvert', name: 'Culvert'},
    {key: 'checkComingSlope', name: 'Slope'},
    {key: 'checkComingTunnel', name: 'Tunnel'},
]
export default {
    name: 'specialInspection',
    data() {
        return {
            tableData: [],
            lastData: [],
            startTime: moment().startOf('year').format('YYYY-MM-DD'),
            endTime: moment().format('YYYY-MM-DD'),
            loading: false,
            cstatus: '',
        }
    },
    created() {
        this.loadData()
    },
    methods: {
        objectSpanMethod({row, column, rowIndex, columnIndex}) {
            if (columnIndex === 0) {
                if (rowIndex % 3 === 0) {
                    return {
                        rowspan: 3,
                        colspan: 1,
                    }
                } else {
                    return {
                        rowspan: 0,
                        colspan: 0,
                    }
                }
            }
            if (columnIndex === 1) {
                if (rowIndex % 3 === 0) {
                    return {
                        rowspan: 3,
                        colspan: 1,
                    }
                } else {
                    return {
                        rowspan: 0,
                        colspan: 0,
                    }
                }
            }
        },
        reset() {
            this.startTime = moment().startOf('year').format('YYYY-MM-DD')
            this.endTime = moment().format('YYYY-MM-DD')
            this.loadData()
        },
        handleReset() {
            let length = this.lastData.length - 1
            if (length === 0) return
            this.tableData = this.formatTableDate(this.lastData[length - 1])
            this.lastData.splice(length, 1)
        },
        hanldeRowClick(row) {
            if (row.chirldren.length == 0) {
                let path = 'regularInspection'
                if (this.cstatus) {
                    path = pathMap.filter((item) => item.key === this.cstatus)[0].path
                }
                return this.$router.push({
                    path,
                })
            } else {
                this.tableData = this.formatTableDate(row.chirldren)
                this.lastData.push(row.chirldren)
            }
        },
        handleCellClick(row, column) {
            this.cstatus = column.columnKey
        },
        loadData() {
            this.loading = true
            let str = `?startDate=${this.startTime}&endDate=${this.endTime}`
            this.$http
                .post('${yhxt}/baseDataStatistics/v1/getSpecialCount' + str)
                .then((res) => {
                    if (res.status == 200 && res.data && res.data.value) {
                        this.tableData = this.formatTableDate(res.data.value)
                        this.lastData.push(res.data.value)
                    }
                    this.loading = false
                })
                .catch(() => {
                    this.loading = false
                })
        },
        formatTableDate(data) {
            let temp = []
            data.forEach((item) => {
                let objFinish = {
                    name: item.name,
                    statusName: '已检查',
                    chirldren: item.chirldren,
                }
                let objUnfinish = {
                    name: item.name,
                    statusName: '未检查',
                    chirldren: item.chirldren,
                }
                let objComing = {
                    name: item.name,
                    statusName: '临期',
                    chirldren: item.chirldren,
                }
                if (item.oftenCheckDto) {
                    let of = item.oftenCheckDto
                    finish.forEach((item) => {
                        objFinish[`of-${item.name}`] = of[item.key]
                    })
                    unfinish.forEach((item) => {
                        objUnfinish[`of-${item.name}`] = of[item.key]
                    })
                    coming.forEach((item) => {
                        objComing[`of-${item.name}`] = of[item.key]
                    })
                }
                if (item.checkFrequentlyDto) {
                    let check = item.checkFrequentlyDto
                    finish.forEach((item) => {
                        objFinish[`check-${item.name}`] = check[item.key]
                    })
                    unfinish.forEach((item) => {
                        objUnfinish[`check-${item.name}`] = check[item.key]
                    })
                    coming.forEach((item) => {
                        objComing[`check-${item.name}`] = check[item.key]
                    })
                }
                if (item.specialProjectInspectionDto) {
                    let special = item.specialProjectInspectionDto
                    finish.forEach((item) => {
                        objFinish[`special-${item.name}`] = special[item.key] || 0
                    })
                    unfinish.forEach((item) => {
                        objUnfinish[`special-${item.name}`] = special[item.key] || 0
                    })
                    coming.forEach((item) => {
                        objComing[`special-${item.name}`] = special[item.key] || 0
                    })
                }
                temp.push(objFinish, objUnfinish, objComing)
            })
            return temp
        },
    },
}
</script>

<style lang="scss" scoped>
/deep/ .el-date-editor {
    background-color: #103c5d;
    border: none;
}
/deep/ .el-range-separator {
    color: #fff;
}
/deep/ .el-table th.is-leaf {
    background-color: transparent !important;
}
/deep/ .el-table__row {
    background-color: #0b426e !important;
}
/deep/ .el-table__row--striped {
    background-color: #124873 !important;
}
/deep/ .el-table__header-wrapper {
    border-top-left-radius: 10px;
    border-top-right-radius: 10px;
}
/deep/ .el-table__body-wrapper {
    border-bottom-left-radius: 10px;
    border-bottom-right-radius: 10px;
}
/deep/ .el-table {
    background-color: transparent;
}
.container {
    padding: 30px;
    
    box-sizing: border-box;

    .header {
        height: 59px;
        width: 100%;
        display: flex;
        justify-content: space-between;
        // border-bottom: 1px solid #4d7faf;
        .title {
            display: flex;
            height: 34px;
            align-items: center;
            .title-icon {
                display: block;
                width: 28px;
                height: 28px;
                background-image: url('../../assets/img/icon-标题@2x.png');
                background-size: 100% 100%;
            }
            .title-text {
                margin-left: 5px;
                height: 34px;
                font-size: 26px;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 700;
                line-height: 34px;
                color: transparent;
                -webkit-background-clip: text;
                background-image: linear-gradient(180deg, #e5f2ff 24%, #1f5c99 100%);
            }
        }
        .back-icon {
            margin-right: 10px;
            cursor: pointer;
            display: block;
            width: 40px;
            height: 40px;
            background-size: 100% 100%;
            background-image: url(../../assets//img/icon-返回@2x.png);
        }
    }
    .search {
        margin-top: 32px;
    }
    .table {
        margin-top: 12px;
        height: calc(100% - 150px);
        width: 100%;
        overflow: auto;
        /deep/.el-table__footer-wrapper tbody td.el-table__cell{
            background-color: #145080 !important;
            .cell{
                line-height: 38px;
                font-size: 16px;
                font-weight: 700;
                color: #e7edf0;
            }
        }
        /deep/ .el-table__footer-wrapper td.el-table__cell {
            border-top: 1px solid #1f5c99!important;
            border-right: 1px solid #1f5c99!important;
        }
        /deep/ .custom-header-cell {
            background-color: #145080 !important;
            padding: 15px 0;
            border-bottom: 1px solid #1f5c99!important;
            border-right: 1px solid #1f5c99!important;
            .cell {
                font-size: 18px;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 700;
                color: #e7edf0;
            }
        }
        /deep/ .custom-cell {
            padding: 15px 0;
            height: 50px;
            cursor: pointer;
            .cell,
            div {
                font-size: 16px;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 400;
                color: #e5f2ff;
            }
        }
        .table-total {
            display: flex;
            justify-content: center;
            align-items: center;
            height: 64px;
            background-color: #145080;
            border-radius: 10px;
            margin-top: 8px;
            span {
                font-size: 18px;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 700;
                color: #e7edf0;
                text-align: center;
                &:nth-child(1) {
                    width: 70px;
                }
                &:nth-child(2) {
                    width: 160px;
                }
                &:not(:nth-child(1)):not(:nth-child(2)) {
                    flex: 1;
                }
            }
        }
    }
    .charts {
        margin-top: 32px;
        display: flex;
        .charts-border {
            position: relative;
            height: 507px;
            flex: 1;
            background-size: 100% 100%;
            background-image: url('../../assets/img/框@2x.png');
            .charts_title {
                display: flex;
                height: 24px;
                align-items: center;
                position: absolute;
                top: 30px;
                left: 20px;
            }
            .charts_title-icon {
                display: block;
                width: 20px;
                height: 20px;
                background-size: 100% 100%;
                background-image: url('../../assets/img/icon-饼图@2x.png');
            }
            .clumn-icon {
                background-image: url('../../assets/img/icon-柱图@2x.png');
            }
            .charts_title-text {
                margin-left: 5px;
                height: 24px;
                font-size: 18px;
                font-family: Microsoft YaHei, Microsoft YaHei;
                font-weight: 700;
                line-height: 24px;
                color: transparent;
                -webkit-background-clip: text;
                background-image: linear-gradient(180deg, #e5f2ff 24%, #1f5c99 100%);
            }
        }
    }
}
</style>
